@@ -1,6 +1,12 @@
 import os
 import pytest
 
+try:
+    # Python < 3.12
+    from importlib_resources import files
+except ImportError:
+    from importlib.resources import files
+
 from contextlib import ExitStack
 from sybil import Sybil
 from doctest import ELLIPSIS, REPORT_NDIFF, NORMALIZE_WHITESPACE
@@ -21,8 +27,8 @@ class DoctestNamespace:
         # sys.path so that the `fruit.py` module (containing an enum for the
         # pickle tests) can be imported.  There's probably a more robust way to
         # do this, but it works and is simple so fix it only if necessary.
-        test_dir = os.path.join(os.getcwd(), 'test')
-        assert os.path.isfile(os.path.join(test_dir, 'fruit.py'))
+        test_dir = files() / 'tests'
+        assert (test_dir / 'fruit.py').is_file()
         self._resources.enter_context(
             pytest.MonkeyPatch.context()).syspath_prepend(test_dir)
 
@@ -37,8 +43,8 @@ pytest_collect_file = Sybil(
     parsers=[
         DocTestParser(optionflags=DOCTEST_FLAGS),
         PythonCodeBlockParser(),
-        ],
+    ],
     pattern='*.rst',
     setup=namespace.setup,
     teardown=namespace.teardown,
-    ).pytest()
+).pytest()
